@@ -77,6 +77,10 @@ OsinfoOs *osinfo_os_new(const gchar *id);
 
 OsinfoDeviceList *osinfo_os_get_devices(OsinfoOs *os, OsinfoFilter *filter);
 OsinfoDeviceList *osinfo_os_get_all_devices(OsinfoOs *os, OsinfoFilter *filter);
+OsinfoDeviceList *osinfo_os_get_devices_by_property(OsinfoOs *os,
+                                                    const char *property,
+                                                    const char *value,
+                                                    gboolean inherited);
 OsinfoDeviceLinkList *osinfo_os_get_device_links(OsinfoOs *os, OsinfoFilter *filter);
 
 OsinfoDeviceLink *osinfo_os_add_device(OsinfoOs *os, OsinfoDevice *dev);
